<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>AddAppDialog</name>
    <message>
        <location filename="addappdialog.ui" line="23"/>
        <source>Dialog</source>
        <translation>ダイアログ</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="33"/>
        <source>Categories</source>
        <translation>カテゴリ</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="45"/>
        <source>Add category</source>
        <translation>カテゴリの追加</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="59"/>
        <source>Delete category</source>
        <translation>カテゴリの削除</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="76"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="121"/>
        <source>Save Changes</source>
        <translation>変更を保存</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="128"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="166"/>
        <source>Quit dialog</source>
        <translation>終了ダイアログ</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="169"/>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="176"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="194"/>
        <source>Select...</source>
        <translation>選択...</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="201"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="208"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="215"/>
        <source>Icon:</source>
        <translation>アイコン:</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="222"/>
        <location filename="addappdialog.cpp" line="122"/>
        <source>Set icon</source>
        <translation>アイコンを設定</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="235"/>
        <source>Run in Terminal</source>
        <translation>ターミナルを実行</translation>
    </message>
    <message>
        <location filename="addappdialog.ui" line="248"/>
        <source>Startup Notifier</source>
        <translation>通知 (Notifier) の起動</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="37"/>
        <source>Add Custom Application</source>
        <translation>カスタムアプリを追加</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="54"/>
        <source>Could not save the file</source>
        <translation>ファイルを保存できません</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save changes?</source>
        <translation>変更を保存？</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Do you want to save your edits?</source>
        <translation>編集した内容を保存しますか？</translation>
    </message>
    <message>
        <location filename="addappdialog.cpp" line="103"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="17"/>
        <location filename="mainwindow.cpp" line="835"/>
        <source>MX Menu Editor</source>
        <translation>MX メニューエディタ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>Advanced Editor</source>
        <translation>高機能なエディタ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="54"/>
        <source>Categories and applications</source>
        <translation>カテゴリーとアプリケーション</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="81"/>
        <source>Add custom application</source>
        <translation>カスタムアプリの追加</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="95"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="104"/>
        <source>Run in terminal</source>
        <translation>ターミナルで実行</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Hide</source>
        <translation>隠す</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="124"/>
        <source>Notify startup</source>
        <translation>通知の起動</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="147"/>
        <source>Quick Editor</source>
        <translation>簡易エディタ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="159"/>
        <source>Comment:</source>
        <translation>コメント:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="169"/>
        <source>Restore original item</source>
        <translation>元の項目を復旧</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="180"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Select...</source>
        <translation>選択...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="204"/>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <source>Icon</source>
        <translation>アイコン</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="265"/>
        <location filename="mainwindow.cpp" line="537"/>
        <source>Change icon</source>
        <translation>アイコンを変更</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="279"/>
        <source>Categories</source>
        <translation>カテゴリ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="305"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="374"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="381"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Display help</source>
        <translation>ヘルプを表示</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="425"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="432"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="451"/>
        <source>Save Changes</source>
        <translation>変更を保存</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="458"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="496"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="503"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select executable file</source>
        <translation>実行ファイルを選択</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="521"/>
        <source>Image Files (*.png *.jpg *.bmp *.xpm)</source>
        <translation>画像ファイル (*.png *.jpg *.bmp *.xpm)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="714"/>
        <source>Choose category</source>
        <translation>カテゴリーを選択</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="725"/>
        <location filename="mainwindow.cpp" line="841"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="726"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="816"/>
        <source>Could not save the file</source>
        <translation>ファイルを保存できません</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="834"/>
        <source>About MX Menu Editor</source>
        <translation>MX メニューエディタについて</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="835"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="836"/>
        <source>Program for editing Xfce menu</source>
        <translation>Xfce メニューを編集するプログラム</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="838"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="839"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="840"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="856"/>
        <source>&amp;Close</source>
        <translation>閉じる(&amp;C)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Save changes?</source>
        <translation>変更を保存？</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="902"/>
        <source>Do you want to save your edits?</source>
        <translation>編集した内容を保存しますか？</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="51"/>
        <source>You must run this program as normal user.</source>
        <translation>このプログラムは標準ユーザーで実行して下さい。</translation>
    </message>
</context>
</TS>